from typing import *


class StringArray:
    def __add__(self, _0: numpy.ndarray, /):
        """
        usage.pandas: 1
        """
        ...


class StringDtype:

    # usage.dask: 1
    kind: object

    def __eq__(self, _0: numpy.dtype, /):
        """
        usage.pandas: 7
        """
        ...

    def __ne__(self, _0: numpy.dtype, /):
        """
        usage.pandas: 1
        """
        ...
